mongo_document_annotation
library
Classes
-
Abs
-
$abs operator
-
Accumulator
-
Basic accumulation operator
-
Add
-
$add operator
-
AddFields
-
$addFields aggregation stage
-
AddToSet
-
$addToSet operator
-
AEIterator<T>
-
Iterator for AEList
-
AEList
-
Aggregation expression's list
-
AEObject
-
Aggregation expression's object
-
AggregateCursor
-
-
AggregateOperation
-
Collection is the collection on which the operation is performed
In case of admin/diagnostic pipeline which does not require an underlying
collection, the db parameter must be passed instead.
-
AggregateOptions
-
-
AggregationExpr
-
Aggregation expression
-
AggregationPipelineBuilder
-
Aggregation pipeline builder
-
AggregationStage
-
Aggregation stage base
-
And
-
$and operator
-
ArrayElemAt
-
$arrayElemAt operator
-
ArrayToObject
-
$arrayToObject operator
-
Avg
-
$avg operator
-
BaseProjections<E>
-
Marker interface for all projections
-
Box
-
https://docs.mongodb.com/manual/reference/operator/query/box/#mongodb-query-op.-box
-
BsonBinary
-
-
BsonBinaryData
-
-
BsonCodec
-
-
BsonLong
-
-
Bucket
-
$bucket aggregation stage
-
BucketAuto
-
$bucketAuto aggregation stage
-
Builder
-
Builder interface
-
Bulk
-
-
BulkWriteResult
-
-
Case
-
Case branch for Switch operator
-
Ceil
-
$ceil operator
-
Center
-
https://docs.mongodb.com/manual/reference/operator/query/box/#mongodb-query-op.-box
-
CenterSphere
-
https://docs.mongodb.com/manual/reference/operator/query/box/#mongodb-query-op.-box
-
ChangeStreamOperation
-
-
ChangeStreamOptions
-
Parameters for the ChangeStream Operation
-
ChunkHandler
-
-
Cmp
-
$cmp operator
-
Codec
-
-
CollationOptions
-
Collation allows users to specify language-specific rules for string
comparison, such as rules for lettercase and accent marks.
@Since(3.4)
-
CommandCursor
-
-
Comparison
-
-
Completer<T>
-
A way to produce Future objects and to complete them later
with a value or error.
-
Concat
-
$concat operator
-
ConcatArrays
-
$concatArrays operator
-
Cond
-
$cond operator
-
Connection
-
-
ConnectionManager
-
-
ConnectionPool
-
A connection pool that limits the number of concurrent connections to a MongoDB server.
-
Const
-
Constant expression
-
Convert
-
$convert operator
-
Count
-
$count aggregation stage
-
CreateCollectionCommand
-
createCollection command.
-
CreateCollectionOptions
-
-
CreateIndexOperation
-
-
CreateIndexOptions
-
@param {object} options Optional settings.
@param {(number|string)}
options.writeConcern The write concern.
@param {boolean} options.unique=false Creates an unique index.
@param {boolean} options.sparse=false Creates a sparse index.
@param {boolean} options.background=false Creates the index in the background, yielding whenever possible.
@param {boolean} options.dropDups=false A unique index cannot be created on a key that has pre-existing duplicate values. If you would like to create the index anyway, keeping the first document the database indexes and deleting all subsequent documents that have duplicate value
@param {number} options.min For geospatial indexes set the lower bound for the co-ordinates.
@param {number} options.max For geospatial indexes set the high bound for the co-ordinates.
@param {number} options.v Specify the format version of the indexes.
@param {number} options.expireAfterSeconds Allows you to expire data on indexes applied to a data (MongoDB 2.2 or higher)
@param {string} options.name Override the autogenerated index name (useful if the resulting name is larger than 128 bytes)
@param {object} options.partialFilterExpression Creates a partial index based on the given filter object (MongoDB 3.2 or higher)
@param {object} options.collation Specify collation (MongoDB 3.4 or higher) settings for update operation (see 3.4 documentation for available fields).
@param {ClientSession} options.session optional session to use for this operation
-
CreateViewCommand
-
createView command.
-
CreateViewOptions
-
-
Cursor
-
-
DateFromParts
-
$dateFromParts
-
DateFromString
-
$dateFromString operator
-
DateTimeConverter
-
-
DateToParts
-
$dateToParts operator
-
DayOfMonth
-
$dayOfMonth operator
-
DayOfWeek
-
$dayOfWeek operator
-
DayOfYear
-
$dayOfYear operator
-
Db
-
-
DbCollection
-
-
DbCommand
-
-
DBPointer
-
-
DBPointerData
-
-
DbRef
-
-
DeleteManyOperation
-
-
DeleteManyOptions
-
-
DeleteManyStatement
-
-
DeleteOneOperation
-
-
DeleteOneOptions
-
-
DeleteOneStatement
-
-
Divide
-
$divide operator
-
EJsonCodec
-
-
Eq
-
$eq operator
-
EventSink<T>
-
A Sink that supports adding errors.
-
Exp
-
$exp operator
-
Expr
-
$expr operator
-
Expression
-
-
Facet
-
$facet aggregation stage
-
Field
-
Field path expression
-
Filter
-
$filter operator
-
FindAndModifyOperation
-
-
FindAndModifyOptions
-
-
FindAndModifyResult
-
-
FindOperation
-
-
FindOptions
-
-
First
-
$first operator
-
Floor
-
$floor operator
-
Future<T>
-
The result of an asynchronous computation.
-
FutureOr<T>
-
A type representing values that are either
Future<T> or T.
-
Geometry
-
https://docs.mongodb.com/manual/reference/operator/query/geometry/#mongodb-query-op.-geometry
-
GeoNear
-
$geoNear
-
GetLastErrorCommand
-
getLastError command.
-
Granularity
-
Granularity for BucketAuto
-
GraphLookup
-
$graphLookup
-
GridFS
-
-
GridFSFile
-
-
GridIn
-
-
GridOut
-
-
Group
-
$group aggregation stage
-
Gt
-
$gt operator
-
Gte
-
$gte operator
-
HelloCommand
-
The Hello command takes the following form:
-
HelloResult
-
Class representing the output of the Hello command
Not all values are represented. If you need something that here is missing
use the execute method that returns the original Map document.
-
Hour
-
$hour operator
-
IfNull
-
$ifNull operator
-
In
-
$in operator
-
IndexOfArray
-
$indexOfArray operator
-
IndexOfBytes
-
$indexOfBytes operator
-
IndexOfCP
-
$indexOfCP operator
-
InsertManyOperation
-
-
InsertManyOptions
-
-
InsertOneOperation
-
-
InsertOneOptions
-
-
IsArray
-
$isArray operator
-
IsoDateFromParts
-
ISO date from parts
-
IsoDayOfWeek
-
$isoDayOfWeek operator
-
IsoWeek
-
$isoWeek operator
-
IsoWeekYear
-
$isoWeekYear operator
-
JsCode
-
This class is used to store Javascript code
-
Last
-
$last operator
-
LegacyUuid
-
This class is a convenient way for managing Binary subtype 3 Bson
types (Uuid Old).
The class holds the content in the format that will be stored in the
data base.
You can directly create the object with .fromHexString(), or
use the format converters for each flavour that have been used
As per today, the flavours I'm aware of are: Java legacy, C# legacy
and Python legacy.
The storing algorithn are the following (found in internet,
please confirm me):
Standard (subtype 4, not covered from this class):
-- From value "00112233-4455-6677-8899-aabbccddeeff"
-- To value "00112233-4455-6677-8899-aabbccddeeff"
Java:
-- From value "00112233-4455-6677-8899-aabbccddeeff"
-- To value "77665544-3322-1100-ffee-ddccbbaa9988"
C#:
-- From value "00112233-4455-6677-8899-aabbccddeeff"
-- To value "33221100-5544-7766-8899-aabbccddeeff"
Python:
-- From value "00112233-4455-6677-8899-aabbccddeeff"
-- To value "00112233-4455-6677-8899-aabbccddeeff"
-
Let
-
$let operator
-
Limit
-
$limit aggregation stage
-
ListCollectionsCursor
-
-
ListIndexesCursor
-
-
Literal
-
Literal expression
-
Ln
-
$ln operator
-
Log
-
$log operator
-
Log10
-
$log10 operator
-
Logical
-
-
Lookup
-
-
Lt
-
$lt operator
-
Lte
-
lte operator
-
Ltrim
-
$ltrim operator
-
MapOp
-
$map operator
-
Match
-
$match aggregation stage
-
Max
-
$max operator
-
MergeObjects
-
$mergeObjects operator
-
MethodCall
-
-
Millisecond
-
$millisecond operator
-
Min
-
$min operator
-
Minute
-
$minute operator
-
Mod
-
$mod operator
-
ModifierBuilder
-
-
MongoDbConnection
-
-
MongoDocument
-
Marks a class as a MongoDB document, giving its collection name.
-
MongoGetMoreMessage
-
-
MongoInsertMessage
-
-
MongoKillCursorsMessage
-
-
MongoMessage
-
-
MongoMessageHandler
-
-
MongoQueryMessage
-
-
MongoRemoveMessage
-
-
MongoReplyMessage
-
-
MongoUpdateMessage
-
-
Month
-
$month operator
-
Multiply
-
$multiply operator
-
MultiStreamController<T>
-
An enhanced stream controller provided by Stream.multi.
-
Ne
-
$ne operator
-
Not
-
$not operator
-
ObjectCodec
-
-
ObjectId
-
-
ObjectIdConverter
-
-
ObjectToArray
-
$objectToArray
-
Operator
-
Basic aggregation operator
-
Or
-
$or operator
-
OrderedBulk
-
-
Output
-
Creates an "output" document for the setWinowsDield stage
-
PacketConverter
-
-
Pow
-
$pow operator
-
Project
-
$project aggregation stage
-
Push
-
$push operator
-
QList<T>
-
-
QMap<T>
-
-
QueryField<T>
-
-
QueryLink<T>
-
-
Range
-
$range operator
-
RawExpression
-
-
ReadPreference
-
The ReadPreference class is a class that represents a MongoDB
ReadPreference and is used to construct connections.
@class
@param {string} mode A string describing the read preference mode (primary|primaryPreferred|secondary|secondaryPreferred|nearest)
@param {array} tags The tags object
@param {object}
options Additional read preference options
@param {number} options.maxStalenessSeconds Max secondary read staleness in seconds, Minimum value is 90 seconds.
@see https://docs.mongodb.com/manual/core/read-preference/
@return {ReadPreference}
-
Reduce
-
$reduce operator
-
RegexFind
-
$regexFind operator
-
RegexFindAll
-
$regexFindAll operator
-
RegexMatch
-
$regexMatch operator
-
ReplaceOneOperation
-
-
ReplaceOneOptions
-
-
ReplaceOneStatement
-
-
ReplaceRoot
-
$replaceRoot aggregation stage
-
ReplaceWith
-
$replaceWith aggregation stage
-
ReverseArray
-
$reverseArray operator
-
Round
-
$round operator
-
Rtrim
-
$rtrim operator
-
Sample
-
$sample aggregation stage
-
SaslContinueCommand
-
-
SaslStartCommand
-
-
SaslStartOptions
-
SaslStart command options;
-
Second
-
$second operator
-
SelectorBuilder
-
-
SerializationParameters
-
-
SerializationRepository
-
-
ServerCapabilities
-
-
ServerConfig
-
-
ServerStatusCommand
-
-
ServerStatusOptions
-
ServerStatus command options;
-
SetStage
-
$set aggregation stage
-
SetWindowFields
-
$setWindowFields aggregation stage
-
ShapeOperator
-
There is
-
Size
-
$size operator
-
Skip
-
$skip aggregation stage
-
Slice
-
$slice operator
-
Sort
-
$sort aggregation stage
-
SortByCount
-
$sortByCount
-
Split
-
$split operator
-
Sqrt
-
$sqrt operator
-
State
-
-
StdDevPop
-
$stdDevPop operator
-
StdDevSamp
-
$stdDevSamp operator
-
StrCaseCmp
-
$strcasecmp operator
-
Stream<T>
-
A source of asynchronous data events.
-
StreamConsumer<S>
-
Abstract interface for a "sink" accepting multiple entire streams.
-
StreamController<T>
-
A controller with the stream it controls.
-
StreamIterator<T>
-
An Iterator-like interface for the values of a Stream.
-
StreamSink<S>
-
A object that accepts stream events both synchronously and asynchronously.
-
StreamSubscription<T>
-
A subscription on events from a Stream.
-
StreamTransformer<S, T>
-
Transforms a Stream.
-
StreamTransformerBase<S, T>
-
Base class for implementing StreamTransformer.
-
StreamView<T>
-
Stream wrapper that only exposes the Stream interface.
-
StrLenBytes
-
$strLenBytes operator
-
StrLenCP
-
$strLenCP operator
-
SubstrBytes
-
$substrBytes operator
-
SubstrCP
-
$substrCP operator
-
Subtract
-
$subtract operator
-
Sum
-
$sum operator
-
Switch
-
$switch operator
-
SynchronousStreamController<T>
-
A stream controller that delivers its events synchronously.
-
Timer
-
A countdown timer that can be configured to fire once or repeatedly.
-
Timestamp
-
-
ToBool
-
$toBool operator
-
ToDate
-
$toDate operator
-
ToDecimal
-
$toDecimal operator
-
ToDouble
-
$toDouble operator
-
ToInt
-
$toInt operator
-
ToLong
-
$toLong operator
-
ToLower
-
$toLower operator
-
ToObjectId
-
$toObjectId operator
-
ToString
-
$toString operator
-
ToUpper
-
$toUpper operator
-
Trim
-
$trim operator
-
Trunc
-
$trunc operator
-
Type
-
$type operator
-
UnionWith
-
$unionWith aggregation stage
-
UnorderedBulk
-
-
Unset
-
$unset aggregation stage
-
Unwind
-
$unwind aggregation stage
-
UpdateManyOperation
-
-
UpdateManyOptions
-
-
UpdateManyStatement
-
-
UpdateOneOperation
-
-
UpdateOneOptions
-
-
UpdateOneStatement
-
-
Var
-
Aggregation expression's variable
-
Week
-
$week operator
-
WriteConcern
-
WriteConcern control the acknowledgment of write operations with various paramaters.
-
WriteResult
-
A wrapper that contains the result status of the mongo shell write methods:
-
Year
-
$year operator
-
Zip
-
$zip operator
-
Zone
-
A zone represents an environment that remains stable across asynchronous
calls.
-
ZoneDelegate
-
An adapted view of the parent zone.
-
ZoneSpecification
-
A parameter object with custom zone function handlers for Zone.fork.
Extensions
-
ChainedQuery
on Expression
-
-
FutureExtensions
on Future<T>
-
Convenience methods on futures.
-
FutureIterable
on Iterable<Future<T>>
-
-
FutureRecord2
on (Future<T1>, Future<T2>)
-
Parallel operations on a record of futures.
-
FutureRecord3
on (Future<T1>, Future<T2>, Future<T3>)
-
Parallel operations on a record of futures.
-
FutureRecord4
on (Future<T1>, Future<T2>, Future<T3>, Future<T4>)
-
Parallel operations on a record of futures.
-
FutureRecord5
on (Future<T1>, Future<T2>, Future<T3>, Future<T4>, Future<T5>)
-
Parallel operations on a record of futures.
-
FutureRecord6
on (Future<T1>, Future<T2>, Future<T3>, Future<T4>, Future<T5>, Future<T6>)
-
Parallel operations on a record of futures.
-
FutureRecord7
on (Future<T1>, Future<T2>, Future<T3>, Future<T4>, Future<T5>, Future<T6>, Future<T7>)
-
Parallel operations on a record of futures.
-
FutureRecord8
on (Future<T1>, Future<T2>, Future<T3>, Future<T4>, Future<T5>, Future<T6>, Future<T7>, Future<T8>)
-
Parallel operations on a record of futures.
-
FutureRecord9
on (Future<T1>, Future<T2>, Future<T3>, Future<T4>, Future<T5>, Future<T6>, Future<T7>, Future<T8>, Future<T9>)
-
Parallel operations on a record of futures.
-
QueryExtensions
on Map<String, dynamic>
-
Functions
-
buildProjectionDoc(List<BaseProjections> projections)
→ Map<String, dynamic>
-
-
collectKeys(dynamic node, Set<String> out)
→ void
-
-
ensureSpecificDateFields(Map<String, dynamic> map, List<String> dateFields)
→ Map<String, dynamic>
-
-
firstEntryToTuple(Map<String, Object>? map)
→ (String, Object)?
-
-
getReadPreferenceModeFromString(String mode)
→ ReadPreferenceMode
-
-
getReadPreferenceModeString(ReadPreferenceMode mode)
→ String
-
-
mergeLookups({required List<Lookup> lookups, List<Map<String, Object>>? existingPipeline, Map<String, dynamic>? queryMap, (String, Object)? sort, int? skip, int? limit})
→ (bool, List<Map<String, Object>>)
-
-
parseIndexOptions(Object fieldOrSpec)
→ Map<String, Object>
-
-
processedValue(dynamic v)
→ dynamic
-
-
resolveReadPreference(dynamic parent, Map<String, Object> options, {bool? inheritReadPreference = true})
→ ReadPreference?
-
Resolves a read preference based on well-defined inheritance rules. This method will not only
determine the read preference (if there is one), but will also ensure the returned value is a
properly constructed instance of
ReadPreference.
-
runZoned<R>(R body(), {Map<Object?, Object?>? zoneValues, ZoneSpecification? zoneSpecification, Function? onError})
→ R
-
Runs
body in its own zone.
-
runZonedGuarded<R>(R body(), void onError(Object error, StackTrace stack), {Map<Object?, Object?>? zoneValues, ZoneSpecification? zoneSpecification})
→ R?
-
Runs
body in its own error zone.
-
sanitizedDocument(Map<String, dynamic> map)
→ Map<String, dynamic>
-
-
scan(Map<String, String> lookupRef, Set<String> prefixes, dynamic node)
→ void
-
-
scheduleMicrotask(void callback())
→ void
-
Runs a function asynchronously.
-
toAggregationPipelineWithMap({Map<String, String> lookupRef = const {}, Map<String, dynamic>? projections, required Map<String, dynamic> raw, (String, int) sort = ("created_at", -1), int limit = 10, int? skip, required Map<String, dynamic> cleaned})
→ (bool, List<Map<String, Object>>)
-
-
unawaited(Future<void>? future)
→ void
-
Explicitly ignores a future.
-
withNoCollisions(List<Map<String, Object>> pipeline)
→ List<Map<String, Object>>
-
Typedefs
-
BsonConstructor<T>
= T Function(Map<String, dynamic>)
-
-
ControllerCallback
= void Function()
-
Type of a stream controller's
onListen, onPause and onResume
callbacks.
-
ControllerCancelCallback
= FutureOr<void> Function()
-
Type of stream controller
onCancel callbacks.
-
CreatePeriodicTimerHandler
= Timer Function(Zone self, ZoneDelegate parent, Zone zone, Duration period, void f(Timer timer))
-
The type of a custom Zone.createPeriodicTimer implementation function.
-
CreateTimerHandler
= Timer Function(Zone self, ZoneDelegate parent, Zone zone, Duration duration, void f())
-
The type of a custom Zone.createTimer implementation function.
-
DbFactory
= FutureOr<Db> Function()
-
A function that produces an instance of Db, whether synchronously or asynchronously.
-
ErrorCallbackHandler
= AsyncError? Function(Zone self, ZoneDelegate parent, Zone zone, Object error, StackTrace? stackTrace)
-
The type of a custom Zone.errorCallback implementation function.
-
ForkHandler
= Zone Function(Zone self, ZoneDelegate parent, Zone zone, ZoneSpecification? specification, Map<Object?, Object?>? zoneValues)
-
The type of a custom Zone.fork implementation function.
-
HandleUncaughtErrorHandler
= void Function(Zone self, ZoneDelegate parent, Zone zone, Object error, StackTrace stackTrace)
-
The type of a custom Zone.handleUncaughtError implementation function.
-
MonadicBlock
= void Function(Map<String, dynamic> value)
-
-
PrintHandler
= void Function(Zone self, ZoneDelegate parent, Zone zone, String line)
-
The type of a custom Zone.print implementation function.
-
RegisterBinaryCallbackHandler
= ZoneBinaryCallback<R, T1, T2> Function<R, T1, T2>(Zone self, ZoneDelegate parent, Zone zone, R f(T1 arg1, T2 arg2))
-
The type of a custom Zone.registerBinaryCallback implementation function.
-
RegisterCallbackHandler
= ZoneCallback<R> Function<R>(Zone self, ZoneDelegate parent, Zone zone, R f())
-
The type of a custom Zone.registerCallback implementation function.
-
RegisterUnaryCallbackHandler
= ZoneUnaryCallback<R, T> Function<R, T>(Zone self, ZoneDelegate parent, Zone zone, R f(T arg))
-
The type of a custom Zone.registerUnaryCallback implementation function.
-
RunBinaryHandler
= R Function<R, T1, T2>(Zone self, ZoneDelegate parent, Zone zone, R f(T1 arg1, T2 arg2), T1 arg1, T2 arg2)
-
The type of a custom Zone.runBinary implementation function.
-
RunHandler
= R Function<R>(Zone self, ZoneDelegate parent, Zone zone, R f())
-
The type of a custom Zone.run implementation function.
-
RunUnaryHandler
= R Function<R, T>(Zone self, ZoneDelegate parent, Zone zone, R f(T arg), T arg)
-
The type of a custom Zone.runUnary implementation function.
-
ScheduleMicrotaskHandler
= void Function(Zone self, ZoneDelegate parent, Zone zone, void f())
-
The type of a custom Zone.scheduleMicrotask implementation function.
-
ZoneBinaryCallback<R, T1, T2>
= R Function(T1, T2)
-
-
ZoneCallback<R>
= R Function()
-
-
ZoneUnaryCallback<R, T>
= R Function(T)
-