Logical class

Implemented types
Available extensions

Constructors

Logical(Expression left, String op, Expression right)

Properties

hashCode int
The hash code for this object.
no setterinherited
left Expression
final
op String
final
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

and<T>(String fieldName) QueryLink<T>

Available on Expression, provided by the ChainedQuery extension

Chains an AND condition for the given fieldName.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toSelectorBuilder() SelectorBuilder
override
toString() String
A string representation of this object.
inherited

Operators

operator &(Expression other) Expression
override
operator ==(Object other) bool
The equality operator.
inherited
operator |(Expression other) Expression
override