QueryField<T> class

Mixed-in types

Constructors

QueryField(String name)

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

contains(String v) Expression
containsAllOf(dynamic value) Expression
inherited
endsWith(String v) Expression
eq(T v) Expression
exists([bool doesExist = true]) Expression
inherited
field<V>(String fieldName) QueryField<V>
geoWithin(ShapeOperator shape) Expression
Only support $geometry shape operator Available ShapeOperator instances: Box , Center, CenterSphere, Geometry
inherited
gt(T v) Expression
gte(T v) Expression
isBetween(dynamic min, dynamic max) Expression
inherited
isIn(dynamic value) Expression
inherited
lt(T v) Expression
lte(T v) Expression
mod(dynamic value) Expression
inherited
ne(T v) Expression
near(dynamic value, [double? maxDistance]) Expression
inherited
nearSphere(String fieldName, Geometry point, {double? maxDistance, double? minDistance}) Expression
Only supports geometry points
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notIn(dynamic value) Expression
inherited
startsWith(String v) Expression
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](String fieldName) QueryField