MoreExMixin mixin
- Mixin applications
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
containsAllOf(
dynamic value) → Expression -
exists(
[bool doesExist = true]) → Expression -
geoWithin(
ShapeOperator shape) → Expression - Only support $geometry shape operator Available ShapeOperator instances: Box , Center, CenterSphere, Geometry
-
isBetween(
dynamic min, dynamic max) → Expression -
isIn(
dynamic value) → Expression -
mod(
dynamic value) → Expression -
near(
dynamic value, [double? maxDistance]) → Expression -
nearSphere(
String fieldName, Geometry point, {double? maxDistance, double? minDistance}) → Expression - Only supports geometry points
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notIn(
dynamic value) → Expression -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited